@@ -6,6 +6,7 @@
 #include "params.h"
 #include "getdata.h"
 #include "row.h"
+#include "conninfoopt.h"
 #include <math.h> // modf
 
 struct ConstantDef
@@ -203,9 +204,9 @@ static PyObject* Connection_script(PyObject* self, PyObject* args)
 }
 
 const char* doc_copy_from_csv =
-    "Connection.copy_from_csv(table, source, header=0) --> None\n"
+    "Connection.copy_from_csv(table, source, header=0) --> int\n"
     "\n"
-    "Executes a COPY FROM command.\n"
+    "Executes a COPY FROM command and returns the number of records copied.\n"
     "\n"
     "table\n"
     "  The table to copy to.  This can also contain the columns to populate.\n"
@@ -353,7 +354,10 @@ static PyObject* Connection_copy_from_csv(PyObject* self, PyObject* args, PyObje
       return SetResultError(final_result.Detach());
     }
 
-    Py_RETURN_NONE;
+    const char* sz = PQcmdTuples(final_result);
+    if (sz == 0 || *sz == 0)
+      Py_RETURN_NONE;
+    return PyLong_FromLong(atoi(sz));
 }
 
 static PyObject* ReturnResult(Connection* cnxn, ResultHolder& result)
@@ -457,6 +461,21 @@ static PyObject* Connection_row(PyObject* self, PyObject* args)
     return Row_New((ResultSet*)rset.Get(), 0);
 }
 
+static PyObject* Connection_info(PyObject* self, PyObject* args) {
+
+    Connection* cnxn = CastConnection(self, REQUIRE_OPEN);
+    if (!cnxn)
+        return 0;
+
+    ConnInfo info(PQconninfo(cnxn->pgconn));
+    if (!info) {
+        return PyErr_NoMemory();
+    }
+
+    return DictFromConnInfo(info);
+}
+
+
 static PyObject* Connection_reset(PyObject* self, PyObject* args)
 {
     Connection* cnxn = CastConnection(self, REQUIRE_OPEN);
@@ -1297,6 +1316,7 @@ static struct PyMethodDef Connection_methods[] =
     { "notify", Connection_notify, METH_VARARGS | METH_KEYWORDS, 0 },
     { "_asyncGetResult", Connection_asyncGetResult, METH_NOARGS, 0 },
     { "_asyncNotifications", Connection_asyncNotifications, METH_NOARGS, 0 },
+    { "info", Connection_info, METH_NOARGS, 0 },
     { 0, 0, 0, 0 }
 };
 
