@@ -158,7 +158,8 @@ def _datapath(filename):
 
 def test_copy_csv(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
-    cnxn.copy_from_csv("t1", open(_datapath('test-noheader.csv')))
+    count = cnxn.copy_from_csv("t1", open(_datapath('test-noheader.csv')))
+    assert count == 2
     assert cnxn.fetchval("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
@@ -167,7 +168,8 @@ def test_copy_csv(cnxn):
 
 def test_copy_csv_header(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
-    cnxn.copy_from_csv("t1", open(_datapath('test-header.csv')), header=True)
+    count = cnxn.copy_from_csv("t1", open(_datapath('test-header.csv')), header=True)
+    assert count == 2
     assert cnxn.fetchval("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
@@ -185,6 +187,7 @@ def test_copy_csv_error(cnxn):
 
 
 def test_copy_csv_gzip(cnxn):
+    # I don't remember why this test is here.  We're feeding it unzipped data.
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", gzip.open(_datapath('test-header.csv.gz')), header=True)
     assert cnxn.fetchval("select count(*) from t1") == 2
@@ -195,7 +198,8 @@ def test_copy_csv_gzip(cnxn):
 
 def test_copy_csv_string(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
-    cnxn.copy_from_csv("t1", '1,"one"\n2,"two"')
+    count = cnxn.copy_from_csv("t1", '1,"one"\n2,"two"')
+    assert count == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -203,7 +207,8 @@ def test_copy_csv_string(cnxn):
 
 def test_copy_csv_string_cols(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
-    cnxn.copy_from_csv("t1(b, a)", '"one",1\n"two",2')  # reverse order of cols
+    count = cnxn.copy_from_csv("t1(b, a)", '"one",1\n"two",2')  # reverse order of cols
+    assert count == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -421,12 +426,14 @@ def test_money(cnxn):
 # parses the values we pass as strings before we even get to pglib.
 
 
+@pytest.mark.skip('LC_ALL locale does not exist')
 def test_decimal_german(cnxn):
     locale.setlocale(locale.LC_ALL, 'de_DE')
     values = [Decimal(s) for s in ['-3.0000000', '123456.7890']]
     _test_type(cnxn, 'decimal(100,7)', values)
 
 
+@pytest.mark.skip('LC_ALL locale does not exist')
 def test_money_german(cnxn):
     locale.setlocale(locale.LC_ALL, 'de_DE')
     values = [Decimal(s) for s in ['1.23', '0.0', '123.45', '-12.34']]
@@ -1118,9 +1125,40 @@ def test_jsonb(cnxn):
     assert value == result
 
 
+def test_jsonb_wrapper(cnxn):
+    value = [1, 2, 3]
+    wrapper = pglib.json(value)
+    cnxn.execute("create table t1(j jsonb)")
+    cnxn.execute("insert into t1 values($1)", wrapper)
+    result = cnxn.fetchval("select j from t1")
+    assert value == result
+
+
 def test_empty_jsonb(cnxn):
     value = {}
     cnxn.execute("create table t1(j jsonb)")
     cnxn.execute("insert into t1 values($1)", value)
     result = cnxn.fetchval("select j from t1")
     assert value == result
+
+
+def test_info(cnxn):
+    info = cnxn.info()
+    assert info['dbname'] == 'test'
+
+    defaults = pglib.defaults()
+    assert isinstance(defaults, dict)
+    assert not defaults.get('dbname')
+
+
+def test_ltree(cnxn):
+    cnxn.execute("create extension if not exists ltree")
+
+    row = cnxn.fetchrow("select oid, typname from pg_type where typname='ltree'")
+    pglib.register_type(row.oid, row.typname)
+
+    cnxn.execute("create table t1(id int, path ltree)")
+    cnxn.execute("insert into t1 values ($1, $2)", 1, "a.b.c")
+    result = cnxn.fetchval("select path from t1")
+    assert result == 'a.b.c'
+
